pyopenssl: Python wrapper module around the OpenSSL library
===========================================================

Description
-----------

Python wrapper module around the OpenSSL library

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/pyOpenSSL/

